@@ -1,6 +1,8 @@
 
 from django.apps import apps
 from django.contrib import admin
+from django.template.loader import render_to_string
+from django.utils.translation import ugettext_lazy as _
 
 from modeltranslation.admin import TranslationAdmin
 
@@ -17,10 +19,10 @@ def get_article_list_display():
 
     list_display += ['created']
 
-    if config.IS_ARTICLE_COMMENTS_ENABLED:
-        list_display += ['is_comments_enabled']
+    if config.ARE_COMMENTS_ENABLED:
+        list_display += ['are_comments_enabled']
 
-    return list_display
+    return list_display + ['preview_tag']
 
 
 def get_article_list_filter():
@@ -32,8 +34,8 @@ def get_article_list_filter():
 
     list_filter += ['created']
 
-    if config.IS_ARTICLE_COMMENTS_ENABLED:
-        list_filter += ['is_comments_enabled']
+    if config.ARE_COMMENTS_ENABLED:
+        list_filter += ['are_comments_enabled']
 
     return list_filter
 
@@ -45,9 +47,16 @@ class ArticleAdmin(TranslationAdmin):
 
     list_filter = get_article_list_filter()
 
-    if config.IS_ARTICLE_TAGS_ENABLED:
+    if config.ARE_TAGS_ENABLED:
         filter_horizontal = ['tags']
 
+    def preview_tag(self, obj):
+        return render_to_string('articles/admin/preview.html', {
+            'file': obj.logo
+        })
+
+    preview_tag.short_description = _('Preview')
+
 
 if config.IS_ARTICLE_TYPE_ENABLED:
 
@@ -58,7 +67,7 @@ if config.IS_ARTICLE_TYPE_ENABLED:
         search_fields = ['name']
 
 
-if config.IS_ARTICLE_TAGS_ENABLED:
+if config.ARE_TAGS_ENABLED:
 
     @admin.register(apps.get_model('articles', 'ArticleTag'))
     class ArticleTagAdmin(TranslationAdmin):
